@@ -103,7 +103,7 @@ bool KonsoleKalendarAdd::addEvent()
                          &loop, &QEventLoop::quit);
         QElapsedTimer t;
         t.start();
-        Q_ASSERT(calendar->incidence(event->uid()) == 0);  // can't exist yet
+        Q_ASSERT(calendar->incidence(event->uid()) == nullptr);  // can't exist yet
         if (!m_variables->allowGui()) {
             Akonadi::IncidenceChanger *changer = calendar->incidenceChanger();
             changer->setShowDialogsOnError(false);
@@ -120,12 +120,11 @@ bool KonsoleKalendarAdd::addEvent()
         calendar->addEvent(event);
         loop.exec();
         qCDebug(KONSOLEKALENDAR_LOG) << "Creation took " << t.elapsed() << "ms.";
-        status = calendar->incidence(event->uid()) != 0;
+        status = calendar->incidence(event->uid()) != nullptr;
         if (status) {
             cout << i18n("Success: \"%1\" inserted",
                          m_variables->getSummary()).toLocal8Bit().data()
                  << endl;
-
         } else {
             cout << i18n("Failure: \"%1\" not inserted",
                          m_variables->getSummary()).toLocal8Bit().data()
@@ -144,8 +143,8 @@ bool KonsoleKalendarAdd::addImportedCalendar()
     FileStorage instore(cal, m_variables->getImportFile());
     if (!instore.load()) {
         qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendaradd.cpp::importCalendar() |"
-            << "Can't import file:"
-            << m_variables->getImportFile();
+                                     << "Can't import file:"
+                                     << m_variables->getImportFile();
         return false;
     }
     Akonadi::CalendarBase::Ptr calendar = m_variables->getCalendar();
@@ -154,7 +153,7 @@ bool KonsoleKalendarAdd::addImportedCalendar()
         Akonadi::IncidenceChanger *changer = calendar->incidenceChanger();
         changer->setShowDialogsOnError(false);
         Akonadi::Collection collection = m_variables->collectionId() != -1 ? Akonadi::Collection(m_variables->collectionId())
-        : Akonadi::Collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
+                                         : Akonadi::Collection(CalendarSupport::KCalPrefs::instance()->defaultCalendarId());
 
         if (!collection.isValid()) {
             cout << i18n("Calendar is invalid. Please specify one with --calendar").toLocal8Bit().data() << "\n";
@@ -166,13 +165,13 @@ bool KonsoleKalendarAdd::addImportedCalendar()
 
     QEventLoop loop;
     QObject::connect(calendar.data(), &Akonadi::CalendarBase::createFinished,
-                        &loop, &QEventLoop::quit);
+                     &loop, &QEventLoop::quit);
     QElapsedTimer t;
-    foreach(const auto &event, cal->rawEvents()) {
-        if (calendar->incidence(event->uid()) != 0) {
+    foreach (const auto &event, cal->rawEvents()) {
+        if (calendar->incidence(event->uid()) != nullptr) {
             if (m_variables->isVerbose()) {
                 cout << i18n("Insert Event skipped, because UID \"%1\" is already known. <Verbose>", event->uid()).toLocal8Bit().data()
-                    << endl;
+                     << endl;
             } else {
                 qCInfo(KONSOLEKALENDAR_LOG) << "Event with UID " << event->uid() << "is already in calendar, skipping import of this Event.";
             }
@@ -180,7 +179,7 @@ bool KonsoleKalendarAdd::addImportedCalendar()
         }
         if (m_variables->isVerbose()) {
             cout << i18n("Add Event with UID \"%1\". <Verbose>", event->uid()).toLocal8Bit().data()
-                << endl;
+                 << endl;
         }
         if (m_variables->isDryRun()) {
             continue;
@@ -188,14 +187,14 @@ bool KonsoleKalendarAdd::addImportedCalendar()
         t.start();
         calendar->addEvent(event);
         loop.exec();
-        qCDebug(KONSOLEKALENDAR_LOG) << "Creation of event took " << t.elapsed() << "ms." << "status: "<< (calendar->incidence(event->uid()) != 0);
-        if (calendar->incidence(event->uid()) == 0) {
+        qCDebug(KONSOLEKALENDAR_LOG) << "Creation of event took " << t.elapsed() << "ms." << "status: "<< (calendar->incidence(event->uid()) != nullptr);
+        if (calendar->incidence(event->uid()) == nullptr) {
             return false;
         }
     }
     qCDebug(KONSOLEKALENDAR_LOG) << "konsolekalendaradd.cpp::importCalendar() |"
-        << "Successfully imported file:"
-        << m_variables->getImportFile();
+                                 << "Successfully imported file:"
+                                 << m_variables->getImportFile();
     return true;
 }
 
